@@ -5,9 +5,15 @@ class Relationship(object):
         :class:`.EntitySet`
     """
 
-    def __init__(self, entityset, parent_dataframe_name, parent_column_name,
-                 child_dataframe_name, child_column_name):
-        """ Create a relationship
+    def __init__(
+        self,
+        entityset,
+        parent_dataframe_name,
+        parent_column_name,
+        child_dataframe_name,
+        child_column_name,
+    ):
+        """Create a relationship
 
         Args:
             entityset (:class:`.EntitySet`): EntitySet to which the relationship belongs
@@ -23,23 +29,30 @@ class Relationship(object):
         self._parent_column_name = parent_column_name
         self._child_column_name = child_column_name
 
-        if (self.parent_dataframe.ww.index is not None and
-                self._parent_column_name != self.parent_dataframe.ww.index):
-            raise AttributeError(f"Parent column '{self._parent_column_name}' is not the index of "
-                                 f"dataframe {self._parent_dataframe_name}")
+        if (
+            self.parent_dataframe.ww.index is not None
+            and self._parent_column_name != self.parent_dataframe.ww.index
+        ):
+            raise AttributeError(
+                f"Parent column '{self._parent_column_name}' is not the index of "
+                f"dataframe {self._parent_dataframe_name}"
+            )
 
     @classmethod
     def from_dictionary(cls, arguments, es):
-        parent_dataframe = arguments['parent_dataframe_name']
-        child_dataframe = arguments['child_dataframe_name']
-        parent_column = arguments['parent_column_name']
-        child_column = arguments['child_column_name']
+        parent_dataframe = arguments["parent_dataframe_name"]
+        child_dataframe = arguments["child_dataframe_name"]
+        parent_column = arguments["parent_column_name"]
+        child_column = arguments["child_column_name"]
         return cls(es, parent_dataframe, parent_column, child_dataframe, child_column)
 
     def __repr__(self):
-        ret = u"<Relationship: %s.%s -> %s.%s>" % \
-            (self._child_dataframe_name, self._child_column_name,
-             self._parent_dataframe_name, self._parent_column_name)
+        ret = "<Relationship: %s.%s -> %s.%s>" % (
+            self._child_dataframe_name,
+            self._child_column_name,
+            self._parent_dataframe_name,
+            self._parent_column_name,
+        )
 
         return ret
 
@@ -47,16 +60,22 @@ class Relationship(object):
         if not isinstance(other, self.__class__):
             return False
 
-        return self._parent_dataframe_name == other._parent_dataframe_name and \
-            self._child_dataframe_name == other._child_dataframe_name and \
-            self._parent_column_name == other._parent_column_name and \
-            self._child_column_name == other._child_column_name
+        return (
+            self._parent_dataframe_name == other._parent_dataframe_name
+            and self._child_dataframe_name == other._child_dataframe_name
+            and self._parent_column_name == other._parent_column_name
+            and self._child_column_name == other._child_column_name
+        )
 
     def __hash__(self):
-        return hash((self._parent_dataframe_name,
-                     self._child_dataframe_name,
-                     self._parent_column_name,
-                     self._child_column_name))
+        return hash(
+            (
+                self._parent_dataframe_name,
+                self._child_dataframe_name,
+                self._parent_column_name,
+                self._child_column_name,
+            )
+        )
 
     @property
     def parent_dataframe(self):
@@ -84,7 +103,7 @@ class Relationship(object):
         if self._is_unique():
             return self._parent_dataframe_name
         else:
-            return '%s[%s]' % (self._parent_dataframe_name, self._child_column_name)
+            return "%s[%s]" % (self._parent_dataframe_name, self._child_column_name)
 
     @property
     def child_name(self):
@@ -92,24 +111,29 @@ class Relationship(object):
         if self._is_unique():
             return self._child_dataframe_name
         else:
-            return '%s[%s]' % (self._child_dataframe_name, self._child_column_name)
+            return "%s[%s]" % (self._child_dataframe_name, self._child_column_name)
 
     def to_dictionary(self):
         return {
-            'parent_dataframe_name': self._parent_dataframe_name,
-            'child_dataframe_name': self._child_dataframe_name,
-            'parent_column_name': self._parent_column_name,
-            'child_column_name': self._child_column_name,
+            "parent_dataframe_name": self._parent_dataframe_name,
+            "child_dataframe_name": self._child_dataframe_name,
+            "parent_column_name": self._parent_column_name,
+            "child_column_name": self._child_column_name,
         }
 
     def _is_unique(self):
         """Is there any other relationship with same parent and child dataframes?"""
         es = self.entityset
         relationships = es.get_forward_relationships(self._child_dataframe_name)
-        n = len([r for r in relationships
-                 if r._parent_dataframe_name == self._parent_dataframe_name])
+        n = len(
+            [
+                r
+                for r in relationships
+                if r._parent_dataframe_name == self._parent_dataframe_name
+            ]
+        )
 
-        assert n > 0, 'This relationship is missing from the entityset'
+        assert n > 0, "This relationship is missing from the entityset"
 
         return n == 1
 
@@ -120,10 +144,12 @@ class RelationshipPath(object):
 
     @property
     def name(self):
-        relationship_names = [_direction_name(is_forward, r)
-                              for is_forward, r in self._relationships_with_direction]
+        relationship_names = [
+            _direction_name(is_forward, r)
+            for is_forward, r in self._relationships_with_direction
+        ]
 
-        return '.'.join(relationship_names)
+        return ".".join(relationship_names)
 
     def dataframes(self):
         if self:
@@ -142,8 +168,9 @@ class RelationshipPath(object):
                 yield relationship._child_dataframe_name
 
     def __add__(self, other):
-        return RelationshipPath(self._relationships_with_direction +
-                                other._relationships_with_direction)
+        return RelationshipPath(
+            self._relationships_with_direction + other._relationships_with_direction
+        )
 
     def __getitem__(self, index):
         return self._relationships_with_direction[index]
@@ -156,18 +183,21 @@ class RelationshipPath(object):
         return len(self._relationships_with_direction)
 
     def __eq__(self, other):
-        return isinstance(other, RelationshipPath) and \
-            self._relationships_with_direction == other._relationships_with_direction
+        return (
+            isinstance(other, RelationshipPath)
+            and self._relationships_with_direction
+            == other._relationships_with_direction
+        )
 
     def __ne__(self, other):
         return not self == other
 
     def __repr__(self):
         if self._relationships_with_direction:
-            path = '%s.%s' % (next(self.dataframes()), self.name)
+            path = "%s.%s" % (next(self.dataframes()), self.name)
         else:
-            path = '[]'
-        return '<RelationshipPath %s>' % path
+            path = "[]"
+        return "<RelationshipPath %s>" % path
 
 
 def _direction_name(is_forward, relationship):
