@@ -1,17 +1,16 @@
 from featuretools.primitives import AggregationPrimitive, TransformPrimitive
 from featuretools.primitives.utils import (
     get_aggregation_primitives,
-    get_transform_primitives
+    get_transform_primitives,
 )
 from featuretools.synthesis.deep_feature_synthesis import DeepFeatureSynthesis
-from featuretools.synthesis.utils import (
-    _categorize_features,
-    get_unused_primitives
-)
+from featuretools.synthesis.utils import _categorize_features, get_unused_primitives
 from featuretools.utils.gen_utils import Library
 
 
-def get_valid_primitives(entityset, target_dataframe_name, max_depth=2, selected_primitives=None):
+def get_valid_primitives(
+    entityset, target_dataframe_name, max_depth=2, selected_primitives=None
+):
     """
     Returns two lists of primitives (transform and aggregation) containing
     primitives that can be applied to the specific target dataframe to create
@@ -54,8 +53,10 @@ def get_valid_primitives(entityset, target_dataframe_name, max_depth=2, selected
                 elif issubclass(prim, TransformPrimitive):
                     prim_list = trans_primitives
                 else:
-                    raise ValueError(f"Selected primitive {prim} is not an "
-                                     "AggregationPrimitive, TransformPrimitive, or str")
+                    raise ValueError(
+                        f"Selected primitive {prim} is not an "
+                        "AggregationPrimitive, TransformPrimitive, or str"
+                    )
             elif prim in available_aggs:
                 prim = available_aggs[prim]
                 prim_list = agg_primitives
@@ -67,15 +68,22 @@ def get_valid_primitives(entityset, target_dataframe_name, max_depth=2, selected
             if df_library in prim.compatibility:
                 prim_list.append(prim)
     else:
-        agg_primitives = [agg for agg in available_aggs.values()
-                          if df_library in agg.compatibility]
-        trans_primitives = [trans for trans in available_trans.values()
-                            if df_library in trans.compatibility]
+        agg_primitives = [
+            agg for agg in available_aggs.values() if df_library in agg.compatibility
+        ]
+        trans_primitives = [
+            trans
+            for trans in available_trans.values()
+            if df_library in trans.compatibility
+        ]
 
-    dfs_object = DeepFeatureSynthesis(target_dataframe_name, entityset,
-                                      agg_primitives=agg_primitives,
-                                      trans_primitives=trans_primitives,
-                                      max_depth=max_depth)
+    dfs_object = DeepFeatureSynthesis(
+        target_dataframe_name,
+        entityset,
+        agg_primitives=agg_primitives,
+        trans_primitives=trans_primitives,
+        max_depth=max_depth,
+    )
 
     features = dfs_object.build_features()
 
