@@ -1,5 +1,11 @@
 # flake8: noqa
 from .mock_ds import make_ecommerce_entityset
-from .features import feature_with_name, backward_path, forward_path, check_rename, check_names
+from .features import (
+    feature_with_name,
+    backward_path,
+    forward_path,
+    check_rename,
+    check_names,
+)
 from .cluster import MockClient, mock_cluster, get_mock_client_cluster
 from .es_utils import get_df_tags, to_pandas
